#[non_exhaustive]pub enum DealError {
WrongHandSize,
WrongStockSize,
RepeatedCard,
}Expand description
Error returned when constructing a Round from an invalid deal
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongHandSize
Each player is dealt exactly 10 cards
WrongStockSize
The stock holds the remaining 31 cards
RepeatedCard
A card appears twice across the hands, upcard, and stock