pub enum Phase {
Upcard,
Draw,
Discard,
Layoff,
Finished,
}Expand description
The phase of a Round
UIs are expected to match on all phases, so this enum is exhaustive.
Variants
Upcard
The initial upcard is offered: take it or pass
Draw
The player to move draws from the stock or the discard pile
Discard
The player to move discards, knocks, or declares big gin
Layoff
The defender may lay off cards onto the knocker’s spread
Finished
The round is over; see Round::result